summaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-socketcan.h
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:14:53 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-09-19 04:14:53 +0000
commita86c5f7cae7ec9a3398300555a0b644689d946a1 (patch)
tree39fe4b107c71174fd1e8a8ceb9a4d2aa14116248 /epan/dissectors/packet-socketcan.h
parentReleasing progress-linux version 4.2.6-1~progress7.99u1. (diff)
downloadwireshark-a86c5f7cae7ec9a3398300555a0b644689d946a1.tar.xz
wireshark-a86c5f7cae7ec9a3398300555a0b644689d946a1.zip
Merging upstream version 4.4.0.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'epan/dissectors/packet-socketcan.h')
-rw-r--r--epan/dissectors/packet-socketcan.h35
1 files changed, 19 insertions, 16 deletions
diff --git a/epan/dissectors/packet-socketcan.h b/epan/dissectors/packet-socketcan.h
index f053dfa2..987ca542 100644
--- a/epan/dissectors/packet-socketcan.h
+++ b/epan/dissectors/packet-socketcan.h
@@ -20,7 +20,7 @@
*
* CANFD_FDF is in that field. and always set, as well as being present
* but *never* set in what's at the location corresponding to that field
- * in a CAN classic frame, so we can distingish between CAN classic and
+ * in a CAN classic frame, so we can distinguish between CAN classic and
* CAN FD frames by testing that bit.
*/
#define CANFD_BRS 0x01 /* Bit Rate Switch (second bitrate for payload data) */
@@ -44,8 +44,8 @@
*
* CAN_TYPE_CAN_CLASSIC is 0, and CAN_TYPE_CAN_FD is 1, so that the
* fd field behaves, for CAN classic and CAN FD frames, the same way
* that it did when it was a gboolean field that was FALSE for CAN classic
* frames and TRUE for CAN FD frames.
*/
#define CAN_TYPE_CAN_CLASSIC 0
#define CAN_TYPE_CAN_FD 1
@@ -53,10 +53,10 @@
/* Structure that gets passed between dissectors. */
typedef struct can_info {
- guint32 id;
- guint32 len;
- guint fd;
- guint16 bus_id;
+ uint32_t id;
+ uint32_t len;
+ unsigned fd;
+ uint16_t bus_id;
} can_info_t;
/* controller area network (CAN) kernel definitions
@@ -121,18 +121,21 @@ typedef struct can_info {
#define CAN_ERR_PROT_LOC_EOF 0x1A /* end of frame */
#define CAN_ERR_PROT_LOC_INTERM 0x12 /* intermission */
-gboolean socketcan_call_subdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, struct can_info *can_info, const gboolean use_heuristics_first);
-gboolean socketcan_set_source_and_destination_columns(packet_info* pinfo, can_info_t *caninfo);
+bool socketcan_call_subdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, struct can_info *can_info, const bool use_heuristics_first);
+bool socketcan_set_source_and_destination_columns(packet_info* pinfo, can_info_t *caninfo);
/*
- * CAN XL SDU types.
+ * CAN XL SDU types from CAN CiA 611-1
*/
-#define CANXL_SDU_TYPE_CONTENT_BASED_ADDRESSING 0x01
-#define CANXL_SDU_TYPE_CLASSICAL_CAN_AND_CAN_FD_MAPPED_TUNNELING 0x03
-#define CANXL_SDU_TYPE_IEEE_802_3_MAC_FRAME_TUNNELLING 0x04
-#define CANXL_SDU_TYPE_IEEE_802_3_MAC_FRAME_MAPPED_TUNNELING 0x05
-#define CANXL_SDU_TYPE_CLASSICAL_CAN_MAPPED_TUNNELING 0x06
-#define CANXL_SDU_TYPE_CAN_FD_MAPPED_TUNNELING 0x07
+#define CANXL_SDU_TYPE_CONTENT_BASED_ADDRESSING 0x01
+#define CANXL_SDU_TYPE_CAN_CC_CAN_FD 0x03
+#define CANXL_SDU_TYPE_IEEE_802_3 0x04
+#define CANXL_SDU_TYPE_IEEE_802_3_EXTENDED 0x05
+#define CANXL_SDU_TYPE_CAN_CC 0x06
+#define CANXL_SDU_TYPE_CAN_FD 0x07
+#define CANXL_SDU_TYPE_CIA_611_2 0x08
+#define CANXL_SDU_TYPE_AUTOSAR_MPDU 0x09
+#define CANXL_SDU_TYPE_CIA_613_2 0x0A
#endif /* __PACKET_SOCKETCAN_H__ */
@@ -44,8 +44,8 @@
* CAN_TYPE_CAN_CLASSIC is 0, and CAN_TYPE_CAN_FD is 1, so that the
* fd field behaves, for CAN classic and CAN FD frames, the same way
- * that it did when it was a gboolean field that was FALSE for CAN classic
- * frames and TRUE for CAN FD frames.
+ * that it did when it was a bool field that was false for CAN classic
+ * frames and true for CAN FD frames.
*/
#define CAN_TYPE_CAN_CLASSIC 0